Class: LinkIO::DeepLinksController
- Inherits:
-
ApplicationController
- Object
- ActionController::Base
- ApplicationController
- LinkIO::DeepLinksController
- Defined in:
- app/controllers/linkio/deep_links_controller.rb
Overview
Handles incoming deep links (GET /link). Stores a pending link for deferred deep linking and redirects to the app or store based on platform.
Instance Method Summary collapse
Instance Method Details
#show ⇒ Object
7 8 9 |
# File 'app/controllers/linkio/deep_links_controller.rb', line 7 def show render_linkio(linkio_client.handle_deep_link(linkio_request)) end |